searchData={"items":[{"type":"module","title":"MDEx","doc":"A fast 100% CommonMark-compatible GitHub Flavored Markdown parser and formatter for Elixir.","ref":"MDEx.html"},{"type":"module","title":"Features - MDEx","doc":"- Fast. Check out the [benchmark](https://github.com/leandrocp/mdex#benchmark)\n- Compatible with the [CommonMark spec](https://spec.commonmark.org) and the [GitHub Flavored Markdown Spec](https://github.github.com/gfm/)\n- Binary is precompiled, no need to compile anything\n- Code syntax highlithging, performed by [Autumn](https://github.com/leandrocp/autumn)\n\nCheck out some samples at https://mdex-c31.pages.dev","ref":"MDEx.html#module-features"},{"type":"module","title":"Installation - MDEx","doc":"Add `:mdex` dependecy:\n\n```elixir\ndef deps do\n  [\n    {:mdex, \"~> 0.1\"}\n  ]\nend\n```","ref":"MDEx.html#module-installation"},{"type":"module","title":"Usage - MDEx","doc":"```elixir\nMix.install([{:mdex, \"~> 0.1\"}])\n```\n\n```elixir\nMDEx.to_html(\"# Hello\")\n#=> \" Hello \\n\"\n```\n\nAnd you can change how the markdown is parsed and formatted by passing options to `MDEx.to_html/2` to enable more features:","ref":"MDEx.html#module-usage"},{"type":"module","title":"GitHub Flavored Markdown with emojis - MDEx","doc":"```elixir\nMDEx.to_html(\n  ~S\"\"\"\n  # GitHub Flavored Markdown :rocket:\n\n  - [x] Task A\n  - [x] Task B\n  - [ ] Task C\n\n  | Feature | Status |\n  | ------- | ------ |\n  | Fast | :white_check_mark: |\n  | GFM  | :white_check_mark: |\n\n  Check out the spec at https://github.github.com/gfm/\n  \"\"\",\n  extension: [\n    strikethrough: true,\n    tagfilter: true,\n    table: true,\n    autolink: true,\n    tasklist: true,\n    footnotes: true,\n    shortcodes: true,\n  ],\n  parse: [\n    smart: true,\n    relaxed_tasklist_matching: true,\n    relaxed_autolinks: true\n  ],\n  render: [\n     github_pre_lang: true,\n     escape: true\n  ]\n) |> IO.puts()\n#=>  GitHub Flavored Markdown 🚀 \n#=>  \n#=>      Task A \n#=>      Task B \n#=>      Task C \n#=>  \n#=>  \n#=>    \n#=>      \n#=>        Feature \n#=>        Status \n#=>      \n#=>    \n#=>    \n#=>      \n#=>        Fast \n#=>        ✅ \n#=>      \n#=>      \n#=>        GFM \n#=>        ✅ \n#=>      \n#=>    \n#=>  \n#=>  Check out the spec at  https://github.github.com/gfm/  \n```","ref":"MDEx.html#module-github-flavored-markdown-with-emojis"},{"type":"module","title":"Code Syntax Highlighting - MDEx","doc":"````elixir\nMDEx.to_html(~S\"\"\"\n```elixir\nString.upcase(\"elixir\")\n```\n\"\"\",\nfeatures: [syntax_highlight_theme: \"catppuccin_latte\"]\n) |> IO.puts()\n#=>  \n#=>    \n#=>      String  .  upcase  (  &quot;elixir&quot;  ) \n#=>    \n#=>  \n````","ref":"MDEx.html#module-code-syntax-highlighting"},{"type":"module","title":"Demo and Samples - MDEx","doc":"A [livebook](https://github.com/leandrocp/mdex/blob/main/playground.livemd) and a [script](https://github.com/leandrocp/mdex/blob/main/playground.exs) are available to play with and experiment with this library, or you can check out all [available samples](https://github.com/leandrocp/mdex/tree/main/priv/generated/samples) at https://mdex-c31.pages.dev","ref":"MDEx.html#module-demo-and-samples"},{"type":"module","title":"Used By - MDEx","doc":"- [BeaconCMS](https://github.com/BeaconCMS/beacon)\n- [Tableau](https://github.com/elixir-tools/tableau)\n\n_Using it and want your project listed here? Please send a PR!_","ref":"MDEx.html#module-used-by"},{"type":"module","title":"Benchmark - MDEx","doc":"A [simple script](benchmark.exs) is available to compare existing libs:\n\n```\nName              ips        average  deviation         median         99th %\ncmark         22.82 K      0.0438 ms    ±16.24%      0.0429 ms      0.0598 ms\nmdex           3.57 K        0.28 ms     ±9.79%        0.28 ms        0.33 ms\nmd             0.34 K        2.95 ms    ±10.56%        2.90 ms        3.62 ms\nearmark        0.25 K        4.04 ms     ±4.50%        4.00 ms        4.44 ms\n\nComparison:\ncmark         22.82 K\nmdex           3.57 K - 6.39x slower +0.24 ms\nmd             0.34 K - 67.25x slower +2.90 ms\nearmark        0.25 K - 92.19x slower +4.00 ms\n```","ref":"MDEx.html#module-benchmark"},{"type":"module","title":"Motivation - MDEx","doc":"* `earmark` is extensible but [can't parse](https://github.com/RobertDober/earmark_parser/issues/126) all kinds of documents and is slow to convert hundreds of markdowns.\n* `md` is very extensible but the doc says \"If one needs to perfectly parse the common markdown, Md is probably not the correct choice\" which is probably the cause for failing to parse many documents.\n* `markdown` is not precompiled and has not received updates in a while.\n* `cmark` is a fast CommonMark parser but it requires compiling the C library, is hard to extend, and was archieved on Apr 2024\n\n_Note that MDEx is the only one that syntax highlights out-of-the-box which contributes to make it slower than cmark._\n\nTo finish, a friendly reminder that all libs have their own strengths and trade-offs.","ref":"MDEx.html#module-motivation"},{"type":"module","title":"Looking for help with your Elixir project? - MDEx","doc":"At DockYard we are [ready to help you build your next Elixir project](https://dockyard.com/phoenix-consulting).\nWe have a unique expertise in Elixir and Phoenix development that is unmatched and we love to [write about Elixir](https://dockyard.com/blog/categories/elixir).\n\nHave a project in mind? [Get in touch](https://dockyard.com/contact/hire-us)!","ref":"MDEx.html#module-looking-for-help-with-your-elixir-project"},{"type":"module","title":"Acknowledgements - MDEx","doc":"* Use Rust's [comrak crate](https://crates.io/crates/comrak) under the hood.\n* [Logo](https://www.flaticon.com/free-icons/rpg) created by by Freepik - Flaticon\n* [Logo font](https://github.com/quoteunquoteapps/CourierPrime) designed by [Alan Greene](https://github.com/a-dg)","ref":"MDEx.html#module-acknowledgements"},{"type":"function","title":"MDEx.to_html/1","doc":"Convert `markdown` to HTML.","ref":"MDEx.html#to_html/1"},{"type":"function","title":"Examples - MDEx.to_html/1","doc":"iex> MDEx.to_html(\"# MDEx\")\n    \" MDEx \\n\"\n\n    iex> MDEx.to_html(\"Implemented with:\\n1. Elixir\\n2. Rust\")\n    \" Implemented with: \\n \\n Elixir \\n Rust \\n \\n\"","ref":"MDEx.html#to_html/1-examples"},{"type":"function","title":"MDEx.to_html/2","doc":"Convert `markdown` to HTML with custom `opts`.","ref":"MDEx.html#to_html/2"},{"type":"function","title":"Options - MDEx.to_html/2","doc":"Accepts all available [Comrak Options](https://docs.rs/comrak/latest/comrak/struct.Options.html) as keyword lists and an extra `:features` option:\n\n* `:extension` - https://docs.rs/comrak/latest/comrak/struct.ExtensionOptions.html\n* `:parse` - https://docs.rs/comrak/latest/comrak/struct.ParseOptions.html\n* `:render` - https://docs.rs/comrak/latest/comrak/struct.RenderOptions.html\n* `:features` - see the available options below","ref":"MDEx.html#to_html/2-options"},{"type":"function","title":"Features Options - MDEx.to_html/2","doc":"* `:sanitize` (default `false`) - sanitize output using [ammonia](https://crates.io/crates/ammonia).\n Recommended if passing `render: [unsafe_: true]`\n* `:syntax_highlight_theme` (default `\"onedark\"`) - syntax highlight code fences using [autumn themes](https://github.com/leandrocp/autumn/tree/main/priv/themes),\nyou should pass the filename without special chars and without extension, for example you should pass `syntax_highlight_theme: \"adwaita_dark\"` to use the [Adwaita Dark](https://github.com/leandrocp/autumn/blob/main/priv/themes/adwaita-dark.toml) theme\n* `:syntax_highlight_inline_style` (default `true`) - embed styles in the output for each generated token. You'll need to [serve CSS themes](https://github.com/leandrocp/autumn?tab=readme-ov-file#linked) if inline styles are disabled to properly highlight code","ref":"MDEx.html#to_html/2-features-options"},{"type":"function","title":"Examples - MDEx.to_html/2","doc":"iex> MDEx.to_html(\"# MDEx\")\n    \" MDEx \\n\"\n\n    iex> MDEx.to_html(\"Implemented with:\\n1. Elixir\\n2. Rust\")\n    \" Implemented with: \\n \\n Elixir \\n Rust \\n \\n\"\n\n    iex> MDEx.to_html(\"Hello ~world~ there\", extension: [strikethrough: true])\n    \" Hello  world  there \\n\"\n\n    iex> MDEx.to_html(\" visit https://https://beaconcms.org \", extension: [autolink: true], render: [unsafe_: true])\n    \"  visit  https://https://beaconcms.org   \\n\"\n\n    iex> MDEx.to_html(\"# Title with  console.log('dangerous script') \", render: [unsafe_: true], features: [sanitize: true])\n    \" Title with  \\n\"","ref":"MDEx.html#to_html/2-examples"},{"type":"task","title":"mix mdex.generate_samples","doc":"","ref":"Mix.Tasks.Mdex.GenerateSamples.html"},{"type":"extras","title":"Changelog","doc":"# Changelog","ref":"changelog.html"},{"type":"extras","title":"0.1.18 (2024-07-13) - Changelog","doc":"","ref":"changelog.html#0-1-18-2024-07-13"},{"type":"extras","title":"Enhancements - Changelog","doc":"* Bump comrak from [0.24.1 to 0.26.0](https://github.com/kivikakk/comrak/blob/9f4d391abe2857031f993c4cdddf1ebba7cdbc7d/changelog.txt#L1-L60)\n  * Add new `extension` options: underline, spoiler, greentext\n  * Add new `render` options: experimental_inline_sourcepos, escaped_char_spans, ignore_setext, ignore_empty_links, gfm_quirks, prefer_fenced","ref":"changelog.html#enhancements"},{"type":"extras","title":"0.1.17 (2024-06-19) - Changelog","doc":"","ref":"changelog.html#0-1-17-2024-06-19"},{"type":"extras","title":"Enhancements - Changelog","doc":"* Relax minimum required Elixir version to 1.13\n  * Bump comrak to 0.24.1\n  * Bump ammonia to 4.0\n  * Add new `extension` options: multiline_block_quotes, math_dollars, math_code, shortcodes, wikilinks_title_after_pipe, wikilinks_title_before_pipe\n  * Add new `render` option: escaped_char_spans\n  * Add new option `features.syntax_highlight_inline_style` to control whether to embed inline styles or not. Default is `true`.","ref":"changelog.html#enhancements"},{"type":"extras","title":"Changed - Changelog","doc":"* Build binaries on MacOS 12","ref":"changelog.html#changed"},{"type":"extras","title":"0.1.16 (2024-04-29) - Changelog","doc":"","ref":"changelog.html#0-1-16-2024-04-29"},{"type":"extras","title":"Enhancements - Changelog","doc":"* Added language `objc` to syntax highlighter.","ref":"changelog.html#enhancements"},{"type":"extras","title":"0.1.15 (2024-04-16) - Changelog","doc":"","ref":"changelog.html#0-1-15-2024-04-16"},{"type":"extras","title":"Enhancements - Changelog","doc":"* Update rustler to `~> 0.32`\n  * Update rustler_precompiled `~> 0.7`\n  * Added legacy targets","ref":"changelog.html#enhancements"},{"type":"extras","title":"Backwards incompatible changes - Changelog","doc":"* Minimum required Elixir version is now 1.14\n  * Removed target `arm-unknown-linux-gnueabihf`\n  * Removed target `riscv64gc-unknown-linux-gnu`","ref":"changelog.html#backwards-incompatible-changes"},{"type":"extras","title":"0.1.14 (2024-04-11) - Changelog","doc":"","ref":"changelog.html#0-1-14-2024-04-11"},{"type":"extras","title":"Backwards incompatible changes - Changelog","doc":"* [Syntax Highlight] Renamed parent ` ` class from `autumn-highlight` to `autumn-hl`\n  * [Syntax Highlight] Added prefix `ahl-` to each scope class","ref":"changelog.html#backwards-incompatible-changes"},{"type":"extras","title":"Enhancements - Changelog","doc":"* Update autumn to 0.2.2 (#33)\n  * Update comrak to 0.20.0 (#27) - @supernintendo","ref":"changelog.html#enhancements"},{"type":"extras","title":"0.1.13 (2023-11-20) - Changelog","doc":"","ref":"changelog.html#0-1-13-2023-11-20"},{"type":"extras","title":"Enhancements - Changelog","doc":"* Update autumn themes to add base16-tomorrow and base16-tomorrow-night - @paradox460","ref":"changelog.html#enhancements"},{"type":"extras","title":"0.1.12 (2023-11-06) - Changelog","doc":"","ref":"changelog.html#0-1-12-2023-11-06"},{"type":"extras","title":"Fixes - Changelog","doc":"* Comrak docs links","ref":"changelog.html#fixes"},{"type":"extras","title":"Enhancements - Changelog","doc":"* Add languages: jsx, tsx, vim\n  * Bump injket v0.10.2","ref":"changelog.html#enhancements"},{"type":"extras","title":"0.1.11 (2023-10-25) - Changelog","doc":"","ref":"changelog.html#0-1-11-2023-10-25"},{"type":"extras","title":"Fixes - Changelog","doc":"* Syntax highlighting - remove newlines to avoid formatting incorrectly","ref":"changelog.html#fixes"},{"type":"extras","title":"0.1.10 (2023-10-24) - Changelog","doc":"","ref":"changelog.html#0-1-10-2023-10-24"},{"type":"extras","title":"Enhancements - Changelog","doc":"* Add translate=\"no\" attr in ` ` tag","ref":"changelog.html#enhancements"},{"type":"extras","title":"Fixes - Changelog","doc":"* Fix Javascript syntax highlight\n  * Fix Typescript syntax highlight","ref":"changelog.html#fixes"},{"type":"extras","title":"0.1.9 (2023-09-29) - Changelog","doc":"","ref":"changelog.html#0-1-9-2023-09-29"},{"type":"extras","title":"Enhancements - Changelog","doc":"* Add logo\n  * Add icon","ref":"changelog.html#enhancements"},{"type":"extras","title":"0.1.8 (2023-09-29) - Changelog","doc":"","ref":"changelog.html#0-1-8-2023-09-29"},{"type":"extras","title":"Enhancements - Changelog","doc":"* Fallback to plain text on invalid language\n  * Syntax highlight injections\n  * Add samples","ref":"changelog.html#enhancements"},{"type":"extras","title":"0.1.7 (2023-09-27) - Changelog","doc":"","ref":"changelog.html#0-1-7-2023-09-27"},{"type":"extras","title":"Enhancements - Changelog","doc":"* Syntax highlight code using tree-sitter and helix editor themes. Use https://github.com/leandrocp/autumn/tree/main/native/inkjet_nif under the hood.","ref":"changelog.html#enhancements"},{"type":"extras","title":"0.1.6 (2023-09-14) - Changelog","doc":"","ref":"changelog.html#0-1-6-2023-09-14"},{"type":"extras","title":"Enhancements - Changelog","doc":"* Load extra themes and syntaxes with https://crates.io/crates/two-face","ref":"changelog.html#enhancements"},{"type":"extras","title":"0.1.5 (2023-09-12) - Changelog","doc":"","ref":"changelog.html#0-1-5-2023-09-12"},{"type":"extras","title":"Enhancements - Changelog","doc":"* Sanitize output with https://crates.io/crates/ammonia\n  * Syntax Highlight with https://crates.io/crates/syntect","ref":"changelog.html#enhancements"},{"type":"extras","title":"0.1.4 (2023-09-11) - Changelog","doc":"","ref":"changelog.html#0-1-4-2023-09-11"},{"type":"extras","title":"Fixes - Changelog","doc":"* Compile on Ubuntu 20 to fix libc version mismatch","ref":"changelog.html#fixes"},{"type":"extras","title":"0.1.3 (2023-09-11) - Changelog","doc":"","ref":"changelog.html#0-1-3-2023-09-11"},{"type":"extras","title":"Enhancements - Changelog","doc":"* NIF version 2.15","ref":"changelog.html#enhancements"},{"type":"extras","title":"0.1.2 (2023-09-11) - Changelog","doc":"","ref":"changelog.html#0-1-2-2023-09-11"},{"type":"extras","title":"Enhancements - Changelog","doc":"* Guard markdown arg","ref":"changelog.html#enhancements"},{"type":"extras","title":"Fixes - Changelog","doc":"* specs","ref":"changelog.html#fixes"},{"type":"extras","title":"0.1.1 (2023-09-11) - Changelog","doc":"","ref":"changelog.html#0-1-1-2023-09-11"},{"type":"extras","title":"Enhancements - Changelog","doc":"* Update Rust to edition 2021\n  * Add `@spec` to public functions","ref":"changelog.html#enhancements"},{"type":"extras","title":"0.1.0 (2023-09-11) - Changelog","doc":"","ref":"changelog.html#0-1-0-2023-09-11"},{"type":"extras","title":"Enhancements - Changelog","doc":"* `MDEx.to_html/1` to convert Markdown to HTML using default options.\n  * `MDEx.to_html/2` to convert Markdown to HTML using custom options.","ref":"changelog.html#enhancements"}],"content_type":"text/markdown","producer":{"name":"ex_doc","version":[48,46,51,52,46,49]}}